==> centercontrol-service-1.0.1-20181213.104220-9-sources.jar: com/bizvane/centercontrolservice/models/vo/CtrlAccountVo.java <==
package com.bizvane.centercontrolservice.models.vo;

import com.bizvane.centercontrolservice.models.po.CtrlAccountPo;

import java.util.List;

/**
 * @author chen.li
 * @date on 2018/6/27 16:15
 * @description 中控账号
 * @Copyright (c) 2018 上海商帆信息科技有限公司-版权所有
 */
public class CtrlAccountVo extends CtrlAccountPo {
    @io.swagger.annotations.ApiModelProperty(value = "管辖企业id", name = "companyIds",example = "companyIds")
    private List<Long> companyIds;//管辖企业id数组
    @io.swagger.annotations.ApiModelProperty(value = "管辖企业name", name = "companyNames",example = "companyNames")
    private String companyNames;//管辖企业name
    @io.swagger.annotations.ApiModelProperty(value = "管辖企业id", name = "verifKey",example = "verifKey")
    private String verifKey;//验证码的key值
    @io.swagger.annotations.ApiModelProperty(value = "验证码的value值", name = "verifValue",example = "verifValue")
    private String verifValue;//验证码的value值
    @io.swagger.annotations.ApiModelProperty(value = "高级查询条件", name = "searchValue",example = "searchValue")
    private String searchValue;//高级查询条件
    @io.swagger.annotations.ApiModelProperty(value = "所属企业ID", name = "sysCompanyId",example = "sysCompanyId")
    private Long sysCompanyId;

    private String kindOfUpdatePWS;

    private Long sysBrandId;

    @io.swagger.annotations.ApiModelProperty(value = "中控账号列表", name = "ctrlAccountIdList",example = "ctrlAccountIdList")
    private List<Long> ctrlAccountIdList;

    //第一次输入密码
    @io.swagger.annotations.ApiModelProperty(value = "第一次输入密码", name = "pwdFirst",example = "123322")
    private String pwdFirst;
    //第二次输入密码
    @io.swagger.annotations.ApiModelProperty(value = "第二次输入密码", name = "pwdFirst",example = "1234432")
    private String pwdSecond;

    @io.swagger.annotations.ApiModelProperty(value = "管辖企业id字符串", name = "companyIdsStr",example = "companyIdsStr")
    private String companyIdsStr;//管辖企业id字符串

    @io.swagger.annotations.ApiModelProperty(value = "当前页",name = "pageNumber",example = "当前页")
    private Integer pageNumber = 1;
    @io.swagger.annotations.ApiModelProperty(value = "页面大小",name = "pageSize",example = "页面大小")
    private Integer pageSize = 20;

    public String getKindOfUpdatePWS() {
        return kindOfUpdatePWS;
    }

    public void setKindOfUpdatePWS(String kindOfUpdatePWS) {
        this.kindOfUpdatePWS = kindOfUpdatePWS;
    }

    public String getCompanyIdsStr() {
        return companyIdsStr;
    }

    public void setCompanyIdsStr(String companyIdsStr) {
        this.companyIdsStr = companyIdsStr;
    }

    public String getSearchValue() {
        return searchValue;
    }

    public void setSearchValue(String searchValue) {
        this.searchValue = searchValue;
    }

    public String getPwdFirst() {
        return pwdFirst;
    }

    public void setPwdFirst(String pwdFirst) {
        this.pwdFirst = pwdFirst;
    }

    public String getPwdSecond() {
        return pwdSecond;
    }

    public void setPwdSecond(String pwdSecond) {
        this.pwdSecond = pwdSecond;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public List<Long> getCompanyIds() {
        return companyIds;
    }

    public void setCompanyIds(List<Long> companyIds) {
        this.companyIds = companyIds;
    }

    public String getCompanyNames() {
        return companyNames;
    }

    public void setCompanyNames(String companyNames) {
        this.companyNames = companyNames;
    }

    public String getVerifKey() {
        return verifKey;
    }

    public void setVerifKey(String verifKey) {
        this.verifKey = verifKey;
    }

    public String getVerifValue() {
        return verifValue;
    }

    public void setVerifValue(String verifValue) {
        this.verifValue = verifValue;
    }

    @Override
    public String toString() {
        return "CtrlAccountVo [companyIds=" + companyIds + ", companyNames="
                + companyNames + ", verifKey=" + verifKey + ", verifValue="
                + verifValue + "]";
    }

    public Integer getPageNumber() {
        return pageNumber;
    }

    public void setPageNumber(Integer pageNumber) {
        this.pageNumber = pageNumber;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public List<Long> getCtrlAccountIdList() {
        return ctrlAccountIdList;
    }

    public void setCtrlAccountIdList(List<Long> ctrlAccountIdList) {
        this.ctrlAccountIdList = ctrlAccountIdList;
    }
}

==> centercontrol-service-2.0.0-20191129.062500-15-sources.jar: com/bizvane/centercontrolservice/models/vo/CtrlAccountVo.java <==
package com.bizvane.centercontrolservice.models.vo;

import com.bizvane.centercontrolservice.models.po.CtrlAccountPo;

import java.util.List;

/**
 * @author chen.li
 * @date on 2018/6/27 16:15
 * @description 中控账号
 * @Copyright (c) 2018 上海商帆信息科技有限公司-版权所有
 */
public class CtrlAccountVo extends CtrlAccountPo {
    @io.swagger.annotations.ApiModelProperty(value = "管辖企业id", name = "companyIds",example = "companyIds")
    private List<Long> companyIds;//管辖企业id数组
    @io.swagger.annotations.ApiModelProperty(value = "管辖企业name", name = "companyNames",example = "companyNames")
    private String companyNames;//管辖企业name
    @io.swagger.annotations.ApiModelProperty(value = "管辖企业id", name = "verifKey",example = "verifKey")
    private String verifKey;//验证码的key值
    @io.swagger.annotations.ApiModelProperty(value = "验证码的value值", name = "verifValue",example = "verifValue")
    private String verifValue;//验证码的value值
    @io.swagger.annotations.ApiModelProperty(value = "高级查询条件", name = "searchValue",example = "searchValue")
    private String searchValue;//高级查询条件
    @io.swagger.annotations.ApiModelProperty(value = "所属企业ID", name = "sysCompanyId",example = "sysCompanyId")
    private Long sysCompanyId;

    private String kindOfUpdatePWS;

    private Long sysBrandId;

    @io.swagger.annotations.ApiModelProperty(value = "中控账号列表", name = "ctrlAccountIdList",example = "ctrlAccountIdList")
    private List<Long> ctrlAccountIdList;

    //第一次输入密码
    @io.swagger.annotations.ApiModelProperty(value = "第一次输入密码", name = "pwdFirst",example = "123322")
    private String pwdFirst;
    //第二次输入密码
    @io.swagger.annotations.ApiModelProperty(value = "第二次输入密码", name = "pwdFirst",example = "1234432")
    private String pwdSecond;

    @io.swagger.annotations.ApiModelProperty(value = "管辖企业id字符串", name = "companyIdsStr",example = "companyIdsStr")
    private String companyIdsStr;//管辖企业id字符串

    @io.swagger.annotations.ApiModelProperty(value = "当前页",name = "pageNumber",example = "当前页")
    private Integer pageNumber = 1;
    @io.swagger.annotations.ApiModelProperty(value = "页面大小",name = "pageSize",example = "页面大小")
    private Integer pageSize = 20;

    private Boolean centerstage;
    private Boolean wechatAccount;

    private String staffCode;
    private String companyWechatAccount;
    private Long staffRoleId;

    public String getKindOfUpdatePWS() {
        return kindOfUpdatePWS;
    }

    public void setKindOfUpdatePWS(String kindOfUpdatePWS) {
        this.kindOfUpdatePWS = kindOfUpdatePWS;
    }

    public String getCompanyIdsStr() {
        return companyIdsStr;
    }

    public void setCompanyIdsStr(String companyIdsStr) {
        this.companyIdsStr = companyIdsStr;
    }

    public String getSearchValue() {
        return searchValue;
    }

    public void setSearchValue(String searchValue) {
        this.searchValue = searchValue;
    }

    public String getPwdFirst() {
        return pwdFirst;
    }

    public void setPwdFirst(String pwdFirst) {
        this.pwdFirst = pwdFirst;
    }

    public String getPwdSecond() {
        return pwdSecond;
    }

    public void setPwdSecond(String pwdSecond) {
        this.pwdSecond = pwdSecond;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public List<Long> getCompanyIds() {
        return companyIds;
    }

    public void setCompanyIds(List<Long> companyIds) {
        this.companyIds = companyIds;
    }

    public String getCompanyNames() {
        return companyNames;
    }

    public void setCompanyNames(String companyNames) {
        this.companyNames = companyNames;
    }

    public String getVerifKey() {
        return verifKey;
    }

    public void setVerifKey(String verifKey) {
        this.verifKey = verifKey;
    }

    public String getVerifValue() {
        return verifValue;
    }

    public void setVerifValue(String verifValue) {
        this.verifValue = verifValue;
    }

    @Override
    public String toString() {
        return "CtrlAccountVo [companyIds=" + companyIds + ", companyNames="
                + companyNames + ", verifKey=" + verifKey + ", verifValue="
                + verifValue + "]";
    }

    public Integer getPageNumber() {
        return pageNumber;
    }

    public void setPageNumber(Integer pageNumber) {
        this.pageNumber = pageNumber;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public List<Long> getCtrlAccountIdList() {
        return ctrlAccountIdList;
    }

    public void setCtrlAccountIdList(List<Long> ctrlAccountIdList) {
        this.ctrlAccountIdList = ctrlAccountIdList;
    }

    public String getStaffCode() {
        return staffCode;
    }

    public void setStaffCode(String staffCode) {
        this.staffCode = staffCode;
    }

    public String getCompanyWechatAccount() {
        return companyWechatAccount;
    }

    public void setCompanyWechatAccount(String companyWechatAccount) {
        this.companyWechatAccount = companyWechatAccount;
    }

    public Long getStaffRoleId() {
        return staffRoleId;
    }

    public void setStaffRoleId(Long staffRoleId) {
        this.staffRoleId = staffRoleId;
    }

    public Boolean getCenterstage() {
        return centerstage;
    }

    public void setCenterstage(Boolean centerstage) {
        this.centerstage = centerstage;
    }

    public Boolean getWechatAccount() {
        return wechatAccount;
    }

    public void setWechatAccount(Boolean wechatAccount) {
        this.wechatAccount = wechatAccount;
    }
}
